==> n3_sdk-1.3.1r03.zip: n3_sdk-1.3.1/lib/framework/n3_setup_src.js <==
/**
 * @N3.ProjectName@ ver.@N3.ProjectVersion@ setup module.
 */
N3.Setup = Class.cast({
    // ###############################
    // ##### CONSTANT PROPERTIES #####
    // ###############################
    Const: {
        // pre-loading timeout
        PRELOAD_TIMEOUT: @N3.PreloadTimeout@,

        // application modules
        APPLICATION_MODULE: "./js/@N3.AppName@@POSTFIX@.js",
                             
        // core data module
        CORE_DATA_MODULE: "./js/@N3.AppName@_core@POSTFIX@.js",

        /**
         * directory settings
         */
        LIBS_BASE: "./js/",                // library directory
        AIMG_BASE: "./image/",             // application image directory

        /**
         * library modules
         */
        LIBRARY_MODULES : [
            "@ISCROLL@@POSTFIX@.js"
        ],

        /**
         * application images
         */
        APPLICATION_IMAGES: [@N3.PreloadImages@],

        /**
         * applicatoin cache availability
         */
        APPLICATION_CACHE: @N3.ApplicationCache@,

        /**
         * download cache availability
         */
        DOWNLOAD_CACHE: @N3.DownloadCache@,

        /**
         * color scheme
         */
        COLOR_SCHEME: {
            default: {
                FONT_COLOR      : "#000000",
                BG_COLOR_NORMAL : "#e0e0e0",
                BG_COLOR_OVER   : "#eeeeee",
                BG_COLOR_PRESSED: "#bdbdbd",
                NAVI_COLOR      : "#rgba(0,0,0,0.3)"
            }
        },

        // get core data
        getCoreData: function() {
            return N3.@N3.CoreDataName@;
        },

        // clear core data
        clearCoreData: function() {
            N3.@N3.CoreDataName@ = void(0);
        }
    }
});

==> n3_sdk-1.3.3r03.zip: n3_sdk-1.3.3/lib/framework/n3_setup_src.js <==
/**
 * @N3.ProjectName@ ver.@N3.ProjectVersion@ setup module.
 */
N3.Setup = Class.cast({
    // ###############################
    // ##### CONSTANT PROPERTIES #####
    // ###############################
    Const: {
        // pre-loading timeout
        PRELOAD_TIMEOUT: @N3.PreloadTimeout@,

        // application modules
        APPLICATION_MODULE: "./js/@N3.AppName@@POSTFIX@.js",
                             
        // core data module
        CORE_DATA_MODULES: [@N3.CoreFiles@],

        /**
         * directory settings
         */
        LIBS_BASE: "./js/",                // library directory
        AIMG_BASE: "./image/",             // application image directory

        /**
         * library modules
         */
        LIBRARY_MODULES : [
            "@ISCROLL@@POSTFIX@.js"
        ],

        /**
         * application images
         */
        APPLICATION_IMAGES: [@N3.PreloadImages@],

        /**
         * applicatoin cache availability
         */
        APPLICATION_CACHE: @N3.ApplicationCache@,

        /**
         * download cache availability
         */
        DOWNLOAD_CACHE: @N3.DownloadCache@,

        /**
         * color scheme
         */
        COLOR_SCHEME: {
            default: {
                FONT_COLOR      : "#000000",
                BG_COLOR_NORMAL : "#e0e0e0",
                BG_COLOR_OVER   : "#eeeeee",
                BG_COLOR_PRESSED: "#bdbdbd",
                NAVI_COLOR      : "#rgba(0,0,0,0.3)"
            }
        },

        // get core data
        getCoreData: function() {
            return N3.@N3.CoreDataName@;
        },

        // clear core data
        clearCoreData: function() {
            N3.@N3.CoreDataName@ = void(0);
        }
    }
});
